import { DockerClientConfig, Registry } from ".";
import { Job } from "..";
export interface CraneCopyProps {
    /**
     * Registry URL to copy container image from.
     */
    readonly srcRegistry: Registry | string;
    /**
     * Registry URL to copy container image to.
     */
    readonly dstRegistry: Registry | string;
    /**
     * Creates the Docker configuration file base on objects settings,
     * used by crane to authenticate against given registries.
     */
    readonly dockerClientConfig?: DockerClientConfig;
    /**
     * The name of the Bootstrap job.
     */
    readonly jobName?: string;
    /**
     * The stage of the Bootstrap job.
     */
    readonly jobStage?: string;
}
export interface ICraneCopy {
    /**
     * Registry URL to copy container image from.
     */
    srcRegistry: Registry | string;
    /**
     * Registry URL to copy container image to.
     */
    dstRegistry: Registry | string;
    /**
     * Creates the Docker configuration file base on objects settings,
     * used by crane to authenticate against given registries.
     */
    dockerClientConfig?: DockerClientConfig;
}
/**
 * Creates a job to copy container images with `crane`.
 * See [`crane`](https://github.com/google/go-containerregistry/tree/main/cmd/crane)
 *
 * Copying an image is useful, if you want to have container images as close
 * as possible to your cluster or servers.
 *
 * This subclass of `Job` will configure following defaults for the superclass:
 *
 * - name: crane-copy
 * - stage: deploy
 * - image: PredefinedImages.CRANE
 *
 */
export declare class CraneCopy extends Job implements ICraneCopy {
    srcRegistry: Registry | string;
    dstRegistry: Registry | string;
    dockerClientConfig?: DockerClientConfig;
    constructor(props: CraneCopyProps);
    render(): any;
}
export interface CranePushProps {
    /**
     * Registry URL to copy container image to.
     */
    readonly dstRegistry: Registry | string;
    /**
     * Path where to find the container image tarball.
     * @default PredefinedVariables.ciProjectDir
     */
    readonly tarPath?: string;
    /**
     * Container image name, searched for in `imagePath` and gets `.tar` appended.
     * @default PredefinedVariables.ciProjectName
     */
    readonly imageName?: string;
    /**
     * The tag the image will be tagged with.
     * @default PredefinedVariables.ciCommitRefName
     * @default PredefinedVariables.ciCommitTag
     */
    readonly imageTag?: string;
    /**
     * Creates the Docker configuration file base on objects settings, to
     * authenticate against given registries. Defaults to a `DockerClientConfig`
     * with login to the official Docker Hub and expecting credentials given as
     * environment variables `REGISTRY_USER` and `REGISTRY_LOGIN`.
     */
    readonly dockerClientConfig?: DockerClientConfig;
    /**
     * The name of the Bootstrap job.
     */
    readonly jobName?: string;
    /**
     * The stage of the Bootstrap job.
     */
    readonly jobStage?: string;
}
export interface ICranePush {
    /**
     * Registry URL to copy container image to.
     */
    dstRegistry: Registry | string;
    /**
     * Path where to find the container image tarball.
     * @default PredefinedVariables.ciProjectDir
     */
    tarPath: string;
    /**
     * Container image name, searched for in `imagePath` and gets `.tar` appended.
     * @default PredefinedVariables.ciProjectName
     */
    imageName: string;
    /**
     * The tag the image will be tagged with.
     * @default PredefinedVariables.ciCommitRefName
     * @default PredefinedVariables.ciCommitTag
     */
    imageTag: string;
    /**
     * Creates the Docker configuration file base on objects settings, to
     * authenticate against given registries. Defaults to a `DockerClientConfig`
     * with login to the official Docker Hub and expecting credentials given as
     * environment variables `REGISTRY_USER` and `REGISTRY_LOGIN`.
     */
    dockerClientConfig: DockerClientConfig;
}
/**
 * Creates a job to push container image to remote container registry with `crane`.
 *
 * The image to copy must be in a `tarball` format. It gets validated with crane
 * and is pushed to `dst_registry` destination registry.
 *
 * This subclass of `Job` will configure following defaults for the superclass:
 *
 * - name: crane-push
 * - stage: deploy
 * - image: PredefinedImages.CRANE
 *
 */
export declare class CranePush extends Job implements ICranePush {
    dstRegistry: Registry | string;
    tarPath: string;
    imageName: string;
    imageTag: string;
    dockerClientConfig: DockerClientConfig;
    constructor(props: CranePushProps);
    render(): any;
}
export interface CranePullProps {
    /**
     *  Registry URL to pull container image from.
     */
    readonly srcRegistry: Registry | string;
    /**
     * Container image with namespace to pull from `srcRegistry`.
     * @default PredefinedVariables.ciProjectName
     */
    readonly imageName?: string;
    /**
     * Tag of the image which will be pulled.
     * @default latest
     */
    readonly imageTag?: string;
    /**
     * Path where to save the container image tarball.
     * @default PredefinedVariables.ciProjectDir
     */
    readonly tarPath?: string;
    /**
     * Creates the Docker configuration file base on objects settings, to
     * authenticate against given registries.
     * @default DockerClientConfig with login to the official Docker Hub
     * and expecting credentials given as environment variables
     * `REGISTRY_USER` and `REGISTRY_LOGIN`.
     */
    readonly dockerClientConfig?: DockerClientConfig;
    /**
     * The name of the Bootstrap job.
     */
    readonly jobName?: string;
    /**
     * The stage of the Bootstrap job.
     */
    readonly jobStage?: string;
}
export interface ICranePull {
    /**
     *  Registry URL to pull container image from.
     */
    srcRegistry: Registry | string;
    /**
     * Container image with namespace to pull from `srcRegistry`.
     * @default PredefinedVariables.ciProjectName
     */
    imageName: string;
    /**
     * Tag of the image which will be pulled.
     * @default latest
     */
    imageTag: string;
    /**
     * Path where to save the container image tarball.
     * @default PredefinedVariables.ciProjectDir
     */
    tarPath: string;
    /**
     * Creates the Docker configuration file base on objects settings, to
     * authenticate against given registries.
     * @default DockerClientConfig with login to the official Docker Hub
     * and expecting credentials given as environment variables
     * `REGISTRY_USER` and `REGISTRY_LOGIN`.
     */
    dockerClientConfig: DockerClientConfig;
}
/**
 * Creates a job to pull container image from remote container registry with `crane`.
 *
 * This subclass of `Job` will configure following defaults for the superclass:
 *
 * - name: crane
 * - stage: pull
 * - image: PredefinedImages.CRANE
 *
 */
export declare class CranePull extends Job implements ICranePull {
    srcRegistry: Registry | string;
    imageName: string;
    imageTag: string;
    tarPath: string;
    dockerClientConfig: DockerClientConfig;
    constructor(props: CranePullProps);
    render(): any;
}
